.. :changelog:

History
-------

.. to_doc

---------------------
16.1.5 (2015-12-22)
---------------------

* Fix another bug that was preventing dependency resolution from
  working in Pulsar.

---------------------
16.1.4 (2015-12-22)
---------------------

* Another setup.py fix for job metrics module.

---------------------
16.1.3 (2015-12-22)
---------------------

* Python 3 fixes and updates for recent Galaxy dev commits.

---------------------
16.1.2 (2015-12-21)
---------------------

* Fix for missing galaxy.tools.parser package in setup.py.
* Fix LICENSE in repository.

---------------------
16.1.1 (2015-12-20)
---------------------

* Fix small issues with dependencies, naming, and versioning with first release.

---------------------
16.1.0 (2015-12-20)
---------------------

* Setup project.

.. _bioblend: https://github.com/galaxyproject/bioblend/
.. _XSD: http://www.w3schools.com/schema/
.. _lxml: http://lxml.de/
.. _xmllint: http://xmlsoft.org/xmllint.html
.. _nose: https://nose.readthedocs.org/en/latest/
